pub struct FeedVersion(pub u16);Expand description
Represents the feed report schema version.
The FeedVersion struct wraps a u16 integer representing the version of the feed report schema.
Examples
use chainlink_data_streams_sdk::feed::FeedVersion;
let version = FeedVersion(1);
println!("Feed version: {}", version.0);Tuple Fields
0: u16Trait Implementations
Sourceimpl Clone for FeedVersion
impl Clone for FeedVersion
Sourcefn clone(&self) -> FeedVersion
fn clone(&self) -> FeedVersion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FeedVersion
impl Debug for FeedVersion
Sourceimpl Hash for FeedVersion
impl Hash for FeedVersion
Sourceimpl PartialEq for FeedVersion
impl PartialEq for FeedVersion
Sourcefn eq(&self, other: &FeedVersion) -> bool
fn eq(&self, other: &FeedVersion) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for FeedVersion
impl Eq for FeedVersion
impl StructuralPartialEq for FeedVersion